summaryrefslogtreecommitdiff
path: root/libavformat/rtpdec_asf.c
diff options
context:
space:
mode:
authorAnton Khirnov <anton@khirnov.net>2011-02-20 11:04:12 +0100
committerRonald S. Bultje <rsbultje@gmail.com>2011-02-20 08:37:15 -0500
commitae628ec1fd7f54c102bf9e667a3edd404b9b9128 (patch)
treee23e5873e32189d50147e7a73956e326f3f1e407 /libavformat/rtpdec_asf.c
parent70aa916e4630bcec14439a2d703074b6d4c890a8 (diff)
avio: rename ByteIOContext to AVIOContext.
Signed-off-by: Ronald S. Bultje <rsbultje@gmail.com>
Diffstat (limited to 'libavformat/rtpdec_asf.c')
-rw-r--r--libavformat/rtpdec_asf.c10
1 files changed, 5 insertions, 5 deletions
diff --git a/libavformat/rtpdec_asf.c b/libavformat/rtpdec_asf.c
index 5d52765110..e7893b3698 100644
--- a/libavformat/rtpdec_asf.c
+++ b/libavformat/rtpdec_asf.c
@@ -72,7 +72,7 @@ static int rtp_asf_fix_header(uint8_t *buf, int len)
}
/**
* The following code is basically a buffered ByteIOContext,
* with the added benefit of returning -EAGAIN (instead of 0)
* on packet boundaries, such that the ASF demuxer can return
* safely and resume business at the next packet.
@@ -82,7 +82,7 @@ static int packetizer_read(void *opaque, uint8_t *buf, int buf_size)
return AVERROR(EAGAIN);
}
-static void init_packetizer(ByteIOContext *pb, uint8_t *buf, int len)
+static void init_packetizer(AVIOContext *pb, uint8_t *buf, int len)
{
init_put_byte(pb, buf, len, 0, NULL, packetizer_read, NULL, NULL);
@@ -95,7 +95,7 @@ int ff_wms_parse_sdp_a_line(AVFormatContext *s, const char *p)
{
int ret = 0;
if (av_strstart(p, "pgmpu:data:application/vnd.ms.wms-hdr.asfv1;base64,", &p)) {
- ByteIOContext pb;
+ AVIOContext pb;
RTSPState *rt = s->priv_data;
int len = strlen(p) * 6 / 8;
char *buf = av_mallocz(len);
@@ -147,7 +147,7 @@ static int asfrtp_parse_sdp_line(AVFormatContext *s, int stream_index,
}
struct PayloadContext {
- ByteIOContext *pktbuf, pb;
+ AVIOContext *pktbuf, pb;
uint8_t *buf;
};
@@ -161,7 +161,7 @@ static int asfrtp_parse_packet(AVFormatContext *s, PayloadContext *asf,
uint32_t *timestamp,
const uint8_t *buf, int len, int flags)
{
- ByteIOContext *pb = &asf->pb;
+ AVIOContext *pb = &asf->pb;
int res, mflags, len_off;
RTSPState *rt = s->priv_data;
@@ -72,7 +72,7 @@ static int rtp_asf_fix_header(uint8_t *buf, int len)
}
/**
- * The following code is basically a buffered ByteIOContext,
+ * The following code is basically a buffered AVIOContext,
* with the added benefit of returning -EAGAIN (instead of 0)
* on packet boundaries, such that the ASF demuxer can return